@@ -19,90 +19,530 @@
 #include "internal/nelem.h"
 
 struct testdata {
-    char *data;             /* TIME string value */
-    int type;               /* GENERALIZED OR UTC */
-    int expected_type;      /* expected type after set/set_string_gmt */
-    int check_result;       /* check result */
-    time_t t;               /* expected time_t*/
-    int cmp_result;         /* comparison to baseline result */
-    int convert_result;     /* conversion result */
+    char *data; /* TIME string value */
+    int type; /* GENERALIZED OR UTC */
+    int expected_type; /* expected type after set/set_string_gmt */
+    int check_result; /* check result */
+    time_t t; /* expected time_t*/
+    int cmp_result; /* comparison to baseline result */
+    int convert_result; /* conversion result */
 };
 
 static struct testdata tbl_testdata_pos[] = {
-    { "0",                 V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, }, /* Bad time */
-    { "ABCD",              V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "0ABCD",             V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "1-700101000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "`9700101000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "19700101000000Z",   V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         0,           0,  0, 0, },
-    { "A00101000000Z",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         0,           0,  0, 0, },
-    { "A9700101000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "1A700101000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "19A00101000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "197A0101000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "1970A101000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "19700A01000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "197001A1000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "1970010A000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "19700101A00000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "197001010A0000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "1970010100A000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "19700101000A00Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "197001010000A0Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "1970010100000AZ",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "700101000000X",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         0,           0,  0, 0, },
-    { "19700101000000X",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 0,           0,  0, 0, },
-    { "19700101000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,           0, -1, 1, }, /* Epoch begins */
-    { "700101000000Z",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,           0, -1, 1, }, /* ditto */
-    { "20380119031407Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,  0x7FFFFFFF,  1, 1, }, /* Max 32bit time_t */
-    { "380119031407Z",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,  0x7FFFFFFF,  1, 1, },
-    { "20371231235959Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,  2145916799,  1, 1, }, /* Just before 2038 */
-    { "20371231235959Z",   V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         0,           0,  0, 1, }, /* Bad UTC time */
-    { "371231235959Z",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,  2145916799,  1, 1, },
-    { "19701006121456Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,    24063296, -1, 1, },
-    { "701006121456Z",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,    24063296, -1, 1, },
-    { "19991231000000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,   946598400,  0, 1, }, /* Match baseline */
-    { "199912310000Z",     V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,   946598400,  0, 1, }, /* In various flavors */
-    { "991231000000Z",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "9912310000Z",       V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "9912310000+0000",   V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "199912310000+0000", V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "9912310000-0000",   V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "199912310000-0000", V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "199912310100+0100", V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "199912302300-0100", V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "199912302300-A000", V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         0,   946598400,  0, 1, },
-    { "199912302300-0A00", V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         0,   946598400,  0, 1, },
-    { "9912310100+0100",   V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
-    { "9912302300-0100",   V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,   946598400,  0, 1, },
+    {
+        "0",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    }, /* Bad time */
+    {
+        "ABCD",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "0ABCD",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "1-700101000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "`9700101000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "19700101000000Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "A00101000000Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "A9700101000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "1A700101000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "19A00101000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "197A0101000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "1970A101000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "19700A01000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "197001A1000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "1970010A000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "19700101A00000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "197001010A0000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "1970010100A000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "19700101000A00Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "197001010000A0Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "1970010100000AZ",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "700101000000X",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "19700101000000X",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        0,
+        0,
+        0,
+        0,
+    },
+    {
+        "19700101000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        0,
+        -1,
+        1,
+    }, /* Epoch begins */
+    {
+        "700101000000Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        0,
+        -1,
+        1,
+    }, /* ditto */
+    {
+        "20380119031407Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        0x7FFFFFFF,
+        1,
+        1,
+    }, /* Max 32bit time_t */
+    {
+        "380119031407Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        0x7FFFFFFF,
+        1,
+        1,
+    },
+    {
+        "20371231235959Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        2145916799,
+        1,
+        1,
+    }, /* Just before 2038 */
+    {
+        "20371231235959Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        0,
+        0,
+        0,
+        1,
+    }, /* Bad UTC time */
+    {
+        "371231235959Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        2145916799,
+        1,
+        1,
+    },
+    {
+        "19701006121456Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        24063296,
+        -1,
+        1,
+    },
+    {
+        "701006121456Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        24063296,
+        -1,
+        1,
+    },
+    {
+        "19991231000000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    }, /* Match baseline */
+    {
+        "199912310000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    }, /* In various flavors */
+    {
+        "991231000000Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "9912310000Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "9912310000+0000",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "199912310000+0000",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "9912310000-0000",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "199912310000-0000",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "199912310100+0100",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "199912302300-0100",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "199912302300-A000",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        0,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "199912302300-0A00",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        0,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "9912310100+0100",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
+    {
+        "9912302300-0100",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        946598400,
+        0,
+        1,
+    },
 };
 
 /* ASSUMES SIGNED TIME_T */
 static struct testdata tbl_testdata_neg[] = {
-    { "19011213204552Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 1,     INT_MIN, -1, 0, },
-    { "691006121456Z",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,    -7472704, -1, 1, },
-    { "19691006121456Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,    -7472704, -1, 1, },
+    {
+        "19011213204552Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        1,
+        INT_MIN,
+        -1,
+        0,
+    },
+    {
+        "691006121456Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        -7472704,
+        -1,
+        1,
+    },
+    {
+        "19691006121456Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        -7472704,
+        -1,
+        1,
+    },
 };
 
 /* explicit casts to time_t short warnings on systems with 32-bit time_t */
 static struct testdata tbl_testdata_pos_64bit[] = {
-    { "20380119031408Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,  (time_t)0x80000000,  1, 1, },
-    { "20380119031409Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_UTCTIME,         1,  (time_t)0x80000001,  1, 1, },
-    { "380119031408Z",     V_ASN1_UTCTIME,         V_ASN1_UTCTIME,         1,  (time_t)0x80000000,  1, 1, },
-    { "20500101120000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 1,  (time_t)0x967b1ec0,  1, 0, },
+    {
+        "20380119031408Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        (time_t)0x80000000,
+        1,
+        1,
+    },
+    {
+        "20380119031409Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_UTCTIME,
+        1,
+        (time_t)0x80000001,
+        1,
+        1,
+    },
+    {
+        "380119031408Z",
+        V_ASN1_UTCTIME,
+        V_ASN1_UTCTIME,
+        1,
+        (time_t)0x80000000,
+        1,
+        1,
+    },
+    {
+        "20500101120000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        1,
+        (time_t)0x967b1ec0,
+        1,
+        0,
+    },
 };
 
 /* ASSUMES SIGNED TIME_T */
 static struct testdata tbl_testdata_neg_64bit[] = {
-    { "19011213204551Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 1, (time_t)-2147483649LL, -1, 0, },
-    { "19000101120000Z",   V_ASN1_GENERALIZEDTIME, V_ASN1_GENERALIZEDTIME, 1, (time_t)-2208945600LL, -1, 0, },
+    {
+        "19011213204551Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        1,
+        (time_t)-2147483649LL,
+        -1,
+        0,
+    },
+    {
+        "19000101120000Z",
+        V_ASN1_GENERALIZEDTIME,
+        V_ASN1_GENERALIZEDTIME,
+        1,
+        (time_t)-2208945600LL,
+        -1,
+        0,
+    },
 };
 
 /* A baseline time to compare to */
 static ASN1_TIME gtime = {
     15,
     V_ASN1_GENERALIZEDTIME,
-    (unsigned char*)"19991231000000Z",
+    (unsigned char *)"19991231000000Z",
     0
 };
 static time_t gtime_t = 946598400;
@@ -115,8 +555,8 @@ static int test_table(struct testdata *tbl, int idx)
     struct testdata *td = &tbl[idx];
     int day, sec;
 
-    atime.data = (unsigned char*)td->data;
-    atime.length = strlen((char*)atime.data);
+    atime.data = (unsigned char *)td->data;
+    atime.length = strlen((char *)atime.data);
     atime.type = td->type;
     atime.flags = 0;
 
@@ -144,9 +584,7 @@ static int test_table(struct testdata *tbl, int idx)
     if (!TEST_true(ASN1_TIME_diff(&day, &sec, &gtime, &atime))) {
         TEST_info("ASN1_TIME_diff(%s) to baseline failed", atime.data);
         error = 1;
-    } else if (!((td->cmp_result == 0 && TEST_true((day == 0 && sec == 0))) ||
-                 (td->cmp_result == -1 && TEST_true((day < 0 || sec < 0))) ||
-                 (td->cmp_result == 1 && TEST_true((day > 0 || sec > 0))))) {
+    } else if (!((td->cmp_result == 0 && TEST_true((day == 0 && sec == 0))) || (td->cmp_result == -1 && TEST_true((day < 0 || sec < 0))) || (td->cmp_result == 1 && TEST_true((day > 0 || sec > 0))))) {
         TEST_info("ASN1_TIME_diff(%s) to baseline bad comparison", atime.data);
         error = 1;
     }
@@ -164,7 +602,7 @@ static int test_table(struct testdata *tbl, int idx)
         int local_error = 0;
         if (!TEST_int_eq(ASN1_TIME_cmp_time_t(ptime, td->t), 0)) {
             TEST_info("ASN1_TIME_set(%ld) compare failed (%s->%s)",
-                    (long)td->t, td->data, ptime->data);
+                (long)td->t, td->data, ptime->data);
             local_error = error = 1;
         }
         if (!TEST_int_eq(ptime->type, td->expected_type)) {
@@ -286,31 +724,31 @@ static unsigned char TOMORROW_GEN_STR[] = "20170826000000Z";
 static unsigned char TODAY_UTC_STR[] = "170825000000Z";
 static unsigned char TOMORROW_UTC_STR[] = "170826000000Z";
 
-#define TODAY_GEN    { sizeof(TODAY_GEN_STR)-1, V_ASN1_GENERALIZEDTIME, TODAY_GEN_STR, 0 }
-#define TOMORROW_GEN { sizeof(TOMORROW_GEN_STR)-1, V_ASN1_GENERALIZEDTIME, TOMORROW_GEN_STR, 0 }
-#define TODAY_UTC    { sizeof(TODAY_UTC_STR)-1, V_ASN1_UTCTIME, TODAY_UTC_STR, 0 }
-#define TOMORROW_UTC { sizeof(TOMORROW_UTC_STR)-1, V_ASN1_UTCTIME, TOMORROW_UTC_STR, 0 }
+#define TODAY_GEN { sizeof(TODAY_GEN_STR) - 1, V_ASN1_GENERALIZEDTIME, TODAY_GEN_STR, 0 }
+#define TOMORROW_GEN { sizeof(TOMORROW_GEN_STR) - 1, V_ASN1_GENERALIZEDTIME, TOMORROW_GEN_STR, 0 }
+#define TODAY_UTC { sizeof(TODAY_UTC_STR) - 1, V_ASN1_UTCTIME, TODAY_UTC_STR, 0 }
+#define TOMORROW_UTC { sizeof(TOMORROW_UTC_STR) - 1, V_ASN1_UTCTIME, TOMORROW_UTC_STR, 0 }
 
 static struct compare_testdata tbl_compare_testdata[] = {
-    { TODAY_GEN,    TODAY_GEN,     0 },
-    { TODAY_GEN,    TODAY_UTC,     0 },
-    { TODAY_GEN,    TOMORROW_GEN, -1 },
-    { TODAY_GEN,    TOMORROW_UTC, -1 },
+    { TODAY_GEN, TODAY_GEN, 0 },
+    { TODAY_GEN, TODAY_UTC, 0 },
+    { TODAY_GEN, TOMORROW_GEN, -1 },
+    { TODAY_GEN, TOMORROW_UTC, -1 },
 
-    { TODAY_UTC,    TODAY_GEN,     0 },
-    { TODAY_UTC,    TODAY_UTC,     0 },
-    { TODAY_UTC,    TOMORROW_GEN, -1 },
-    { TODAY_UTC,    TOMORROW_UTC, -1 },
+    { TODAY_UTC, TODAY_GEN, 0 },
+    { TODAY_UTC, TODAY_UTC, 0 },
+    { TODAY_UTC, TOMORROW_GEN, -1 },
+    { TODAY_UTC, TOMORROW_UTC, -1 },
 
-    { TOMORROW_GEN, TODAY_GEN,     1 },
-    { TOMORROW_GEN, TODAY_UTC,     1 },
-    { TOMORROW_GEN, TOMORROW_GEN,  0 },
-    { TOMORROW_GEN, TOMORROW_UTC,  0 },
+    { TOMORROW_GEN, TODAY_GEN, 1 },
+    { TOMORROW_GEN, TODAY_UTC, 1 },
+    { TOMORROW_GEN, TOMORROW_GEN, 0 },
+    { TOMORROW_GEN, TOMORROW_UTC, 0 },
 
-    { TOMORROW_UTC, TODAY_GEN,     1 },
-    { TOMORROW_UTC, TODAY_UTC,     1 },
-    { TOMORROW_UTC, TOMORROW_GEN,  0 },
-    { TOMORROW_UTC, TOMORROW_UTC,  0 }
+    { TOMORROW_UTC, TODAY_GEN, 1 },
+    { TOMORROW_UTC, TODAY_UTC, 1 },
+    { TOMORROW_UTC, TOMORROW_GEN, 0 },
+    { TOMORROW_UTC, TOMORROW_UTC, 0 }
 };
 
 static int test_table_compare(int idx)
@@ -372,7 +810,7 @@ static int test_time_dup(void)
     }
 
     ret = 1;
- err:
+err:
     ASN1_STRING_free(asn1_time);
     ASN1_STRING_free(asn1_gentime);
     ASN1_STRING_free(asn1_time_dup);
